---
icon: material/file-code
---

# Encodings

Available encodings to be imported in the semantics encoding.
These encodings provide useful functionality for working with a new grammar and their interactions.

!!! tip "Usage"
    Import them in your semantics encoding using `#import "metasp.<file_name>.lp".`
